import { text, boolean, select, withKnobs } from '@storybook/addon-knobs'

import { MyButton, MyButtonGroup } from '../components'
import { ButtonSize, ButtonTypes } from '../components/Button'

export default {
  component: MyButton,
  title: 'Design System/Button',
  decorators: [withKnobs],
  excludeStories: /.*Data$/
}

export const configurable = () => ({
  components: { MyButton },
  template: `<my-button
               :disabled="disabled"
               :loading="loading"
               :tooltip="tooltip"
               :icon="type === 'tertiary' ? 'back' : ''"
               :type="type"
               :size="size"
               @click="handleClick"
             >
               {{ type !== 'tertiary' ? 'Default' : '' }}
             </my-button>`,
  props: {
    disabled: {
      default: boolean('Disabled', false)
    },
    loading: {
      default: boolean('Loading', false)
    },
    type: {
      default: select('Type', Object.values(ButtonTypes), ButtonTypes.PRIMARY)
    },
    size: {
      default: select('Size', Object.values(ButtonSize), ButtonSize.BIG)
    },
    tooltip: {
      default: text('Tooltip', '')
    }
  },
  methods: {
    handleClick: () => alert('clicked')
  }
})

export const differentTypesData = Object.values(ButtonTypes).map(type => {
  const label = type[0].toUpperCase() + type.slice(1)
  const data = { type } as any
  if (type === ButtonTypes.TERTIARY) {
    data.icon = 'back'
    data.tooltip = label
  } else {
    data.label = label
  }
  return data
})
export const withDifferentTypes = () => ({
  components: { MyButton },
  template: `<el-row class="flex" style="flex: 1; justify-content: space-between; align-items: center;">
               <my-button
                 v-for="item in items"
                 :key="item.type"
                 :type="item.type"
                 :tooltip="item.tooltip"
                 :icon="item.icon"
               >
                 {{ item.label }}
               </my-button>
             </el-row>`,
  props: {
    items: {
      default: () => differentTypesData
    }
  }
})

export const differentSizeData = Object.values(ButtonSize).map(size =>
  ({ size, label: size[0].toUpperCase() + size.slice(1) }))
export const withDifferentSize = () => ({
  components: { MyButton },
  template: `<el-row class="flex" style="flex: 1; justify-content: space-between; align-items: center;">
               <my-button
                 v-for="item in items"
                 :key="item.size"
                 :size="item.size"
               >
                 {{ item.label }}
               </my-button>
             </el-row>`,
  props: {
    items: {
      default: () => differentSizeData
    }
  }
})

export const disabled = () => ({
  components: { MyButton },
  template: `<el-row class="flex" style="flex: 1; justify-content: space-between; align-items: center;">
               <my-button
                 v-for="item in items"
                 :key="item.type"
                 :type="item.type"
                 :tooltip="item.tooltip"
                 :icon="item.icon"
                 disabled
               >
                 {{ item.label }}
               </my-button>
             </el-row>`,
  props: {
    items: {
      default: () => differentTypesData
    }
  }
})

export const loading = () => ({
  components: { MyButton },
  template: `<el-row class="flex" style="flex: 1; justify-content: space-between; align-items: center;">
               <my-button
                 v-for="item in items"
                 :key="item.type"
                 :type="item.type"
                 :tooltip="item.tooltip"
                 :icon="item.icon"
                 :loading="true"
               >
                 {{ item.label }}
               </my-button>
             </el-row>`,
  props: {
    items: {
      default: () => differentTypesData
    }
  }
})

export const buttonGroup = () => ({
  components: { MyButton, MyButtonGroup },
  template: `<el-row class="flex" style="flex: 1; justify-content: space-between; align-items: center;">
               <my-button-group>
                 <my-button type="primary">Append</my-button>
                 <my-button type="delete">Remove</my-button>
               </my-button-group>
             </el-row>`
})
